@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -21,7 +21,7 @@
 /*!
   @file    value.hpp
   @brief   Value interface and concrete subclasses
-  @version $Rev: 2453 $
+  @version $Rev: 3201 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    09-Jan-04, ahu: created
@@ -493,9 +493,9 @@ namespace Exiv2 {
         //@{
         AutoPtr clone() const { return AutoPtr(clone_()); }
         /*!
-          @brief Write the value to an output stream. Any trailing '\\0'
-                 characters of the ASCII value are stripped and not written to
-                 the output stream.
+          @brief Write the ASCII value up to the the first '\\0' character to an
+                 output stream.  Any further characters are ignored and not
+                 written to the output stream.
         */
         virtual std::ostream& write(std::ostream& os) const;
         //@}
@@ -981,8 +981,7 @@ namespace Exiv2 {
         //@}
 
         //! Simple Date helper structure
-        EXIV2API struct Date
-        {
+        struct EXIV2API Date {
             Date() : year(0), month(0), day(0) {}
             int year;                           //!< Year
             int month;                          //!< Month
